@@ -1,21 +1,8 @@
 /*  This file is part of the KDE libraries
 
-    Copyright (c) 2002 John Firebaugh <jfirebaugh@kde.org>
+    SPDX-FileCopyrightText: 2002 John Firebaugh <jfirebaugh@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kio_about.h"
@@ -25,6 +12,13 @@
 
 using namespace KIO;
 
+// Pseudo plugin class to embed meta data
+class KIOPluginForMetaData : public QObject
+{
+    Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.kde.kio.slave.about" FILE "about.json")
+};
+
 AboutProtocol::AboutProtocol(const QByteArray &pool_socket, const QByteArray &app_socket)
     : SlaveBase("about", pool_socket, app_socket)
 {
@@ -37,21 +31,21 @@ AboutProtocol::~AboutProtocol()
 void AboutProtocol::get( const QUrl& )
 {
     QByteArray output;
-    
+
     QTextStream os( &output, QIODevice::WriteOnly );
     os.setCodec( "ISO-8859-1" ); // In fact ASCII
 
     os << "<html><head><title>about:blank</title></head><body></body></html>";
     os.flush();
 
-    mimeType("text/html");
+    mimeType(QStringLiteral("text/html"));
     data( output );
     finished();
 }
 
 void AboutProtocol::mimetype( const QUrl& )
 {
-    mimeType("text/html");
+    mimeType(QStringLiteral("text/html"));
     finished();
 }
 
@@ -59,7 +53,7 @@ extern "C" Q_DECL_EXPORT int kdemain( int argc, char **argv )
 {
     QCoreApplication app(argc, argv);
 
-    app.setApplicationName("kio_about");
+    app.setApplicationName(QStringLiteral("kio_about"));
 
     if (argc != 4)
     {
@@ -73,3 +67,4 @@ extern "C" Q_DECL_EXPORT int kdemain( int argc, char **argv )
     return 0;
 }
 
+#include "kio_about.moc"
