@@ -1,21 +1,7 @@
 /*
- *   Copyright (C) 2012 - 2016 by Ivan Cukic <ivan.cukic@kde.org>
+ *   SPDX-FileCopyrightText: 2012-2016 Ivan Cukic <ivan.cukic@kde.org>
  *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License or (at your option) version 3 or any later version
- *   accepted by the membership of KDE e.V. (or its successor approved
- *   by the membership of KDE e.V.), which shall act as a proxy
- *   defined in Section 14 of version 3 of the license.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "FileItemLinkingPluginActionLoader.h"
@@ -81,14 +67,14 @@ void FileItemLinkingPluginActionLoader::run()
         }
 
     } else {
-        auto connectionName =
+        const QString connectionName =
             QStringLiteral("kactivities_db_resources_")
             + QString::number((quintptr) this);
 
         {
             auto database = QSqlDatabase::addDatabase(
-                QStringLiteral("QSQLITE"),
-                connectionName);
+                                QStringLiteral("QSQLITE"),
+                                connectionName);
 
             database.setDatabaseName(
                 QStandardPaths::writableLocation(
@@ -98,12 +84,12 @@ void FileItemLinkingPluginActionLoader::run()
             if (database.open()) {
 
                 static const auto queryString = QStringLiteral(
-                    "SELECT usedActivity, COUNT(targettedResource) "
-                    "FROM ResourceLink "
-                    "WHERE targettedResource IN (%1) "
-                        "AND initiatingAgent = \":global\" "
-                        "AND usedActivity != \":global\" "
-                    "GROUP BY usedActivity");
+                                                    "SELECT usedActivity, COUNT(targettedResource) "
+                                                    "FROM ResourceLink "
+                                                    "WHERE targettedResource IN (%1) "
+                                                    "AND initiatingAgent = \":global\" "
+                                                    "AND usedActivity != \":global\" "
+                                                    "GROUP BY usedActivity");
 
                 QStringList escapedFiles;
                 QSqlField field;
@@ -167,7 +153,7 @@ void FileItemLinkingPluginActionLoader::run()
         QSqlDatabase::removeDatabase(connectionName);
     }
 
-    emit result(actions);
+    Q_EMIT result(actions);
 }
 
 Action
