@@ -7,10 +7,7 @@
 #ifndef __kio_man_h__
 #define __kio_man_h__
 
-
-
 #include <QBuffer>
-#include <QTextStream>
 
 #include <kio/global.h>
 #include <kio/slavebase.h>
@@ -20,8 +17,7 @@ class MANProtocol : public QObject, public KIO::SlaveBase
     Q_OBJECT
 
 public:
-
-    MANProtocol(const QByteArray &pool_socket, const QByteArray &app_socket);
+    explicit MANProtocol(const QByteArray &pool_socket, const QByteArray &app_socket);
     ~MANProtocol() override;
 
     void get(const QUrl& url) override;
@@ -30,19 +26,20 @@ public:
     void mimetype(const QUrl &url) override;
     void listDir(const QUrl &url) override;
 
-    void outputError(const QString& errmsg);
-    void outputMatchingPages(const QStringList &matchingPages);
-
-    void showMainIndex();
-    void showIndex(const QString& section);
-
     // the following two functions are the interface to man2html
     void output(const char *insert);
     char *readManPage(const char *filename);
 
     static MANProtocol *self();
 
+    void showIndex(const QString& section);
+
 private:
+    void outputError(const QString& errmsg);
+    void outputMatchingPages(const QStringList &matchingPages);
+
+    void showMainIndex();
+
     void checkManPaths();
     QStringList manDirectories();
     QMap<QString, QString> buildIndexMap(const QString& section);
@@ -54,20 +51,21 @@ private:
 
     QStringList buildSectionList(const QStringList& dirs) const;
     void constructPath(QStringList& constr_path, QStringList constr_catmanpath);
+    QStringList findManPagesInSection(const QString &dir, const QString &title, bool full_path);
 
     void outputHeader(QTextStream &os, const QString &header, const QString &title = QString());
 
+    bool getProgramPath();
+
 private:
-    static MANProtocol *_self;
+    static MANProtocol *s_self;
     QByteArray lastdir;
 
-    void findManPagesInSection(const QString &dir, const QString &title, bool full_path, QStringList &list);
     QStringList m_manpath; ///< Path of man directories
     QStringList m_mandbpath; ///< Path of catman directories
-    QStringList section_names;
+    QStringList m_sectionNames;
 
     QString mySgml2RoffPath;
-    void getProgramPath();
 
     QBuffer m_outputBuffer; ///< Buffer for the output
     QByteArray m_manCSSFile; ///< Path to kio_man.css
