@@ -1,24 +1,13 @@
 /*
  *  Main implementation for KIO-MTP
- *  Copyright (C) 2012  Philipp Schmidt <philschmidt@gmx.net>
- *  Copyright (C) 2018 Andreas Krutzler <andreas.krutzler@gmx.net>
+ *  SPDX-FileCopyrightText: 2012 Philipp Schmidt <philschmidt@gmx.net>
+ *  SPDX-FileCopyrightText: 2018 Andreas Krutzler <andreas.krutzler@gmx.net>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License along
- *  with this program; if not, write to the Free Software Foundation, Inc.,
- *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "kio_mtp.h"
+#include "kio_mtp_debug.h"
 
 // #include <KComponentData>
 #include <QTemporaryFile>
@@ -34,6 +23,13 @@
 #include "kmtpdeviceinterface.h"
 #include "kmtpstorageinterface.h"
 
+// Pseudo plugin class to embed meta data
+class KIOPluginForMetaData : public QObject
+{
+    Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.kde.kio.slave.mtp" FILE "mtp.json")
+};
+
 static UDSEntry getEntry(const KMTPDeviceInterface *device)
 {
     UDSEntry entry;
@@ -101,8 +97,6 @@ static QString convertPath(const QString &slavePath)
 ///////////////////////////// Slave Implementation ///////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
-Q_LOGGING_CATEGORY(LOG_KIO_MTP, "kde.kio-mtp")
-
 extern "C"
 int Q_DECL_EXPORT kdemain(int argc, char **argv)
 {
@@ -185,7 +179,7 @@ void MTPSlave::listDir(const QUrl &url)
     entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IWGRP | S_IXGRP | S_IROTH | S_IXOTH);
     listEntry(entry);
 
-    const QStringList pathItems = url.path().split(QLatin1Char('/'), QString::SkipEmptyParts);
+    const QStringList pathItems = url.path().split(QLatin1Char('/'), Qt::SkipEmptyParts);
     // list devices
     if (pathItems.isEmpty()) {
         qCDebug(LOG_KIO_MTP) << "Root directory, listing devices";
@@ -278,7 +272,7 @@ void MTPSlave::stat(const QUrl &url)
         return;
     }
 
-    const QStringList pathItems = url.path().split(QLatin1Char('/'), QString::SkipEmptyParts);
+    const QStringList pathItems = url.path().split(QLatin1Char('/'), Qt::SkipEmptyParts);
     UDSEntry entry;
     // root
     if (pathItems.size() < 1) {
@@ -344,7 +338,7 @@ void MTPSlave::mimetype(const QUrl &url)
         return;
     }
 
-    const QStringList pathItems = url.path().split(QLatin1Char('/'), QString::SkipEmptyParts);
+    const QStringList pathItems = url.path().split(QLatin1Char('/'), Qt::SkipEmptyParts);
     if (pathItems.size() > 2) {
         const KMTPDeviceInterface *mtpDevice = m_kmtpDaemon.deviceFromName(pathItems.first());
         if (mtpDevice) {
@@ -377,7 +371,7 @@ void MTPSlave::get(const QUrl &url)
         return;
     }
 
-    const QStringList pathItems = url.path().split(QLatin1Char('/'), QString::SkipEmptyParts);
+    const QStringList pathItems = url.path().split(QLatin1Char('/'), Qt::SkipEmptyParts);
 
     // file
     if (pathItems.size() > 2) {
@@ -439,7 +433,7 @@ void MTPSlave::put(const QUrl &url, int, JobFlags flags)
         return;
     }
 
-    const QStringList destItems = url.path().split(QLatin1Char('/'), QString::SkipEmptyParts);
+    const QStringList destItems = url.path().split(QLatin1Char('/'), Qt::SkipEmptyParts);
 
     // can't copy to root or device, needs storage
     if (destItems.size() < 2) {
@@ -537,7 +531,7 @@ void MTPSlave::copy(const QUrl &src, const QUrl &dest, int, JobFlags flags)
             return;
         }
 
-        QStringList destItems = dest.path().split(QLatin1Char('/') , QString::SkipEmptyParts);
+        QStringList destItems = dest.path().split(QLatin1Char('/'), Qt::SkipEmptyParts);
 
         // can't copy to root or device, needs storage
         if (destItems.size() < 2) {
@@ -623,7 +617,7 @@ void MTPSlave::copy(const QUrl &src, const QUrl &dest, int, JobFlags flags)
             return;
         }
 
-        const QStringList srcItems = src.path().split(QLatin1Char('/'), QString::SkipEmptyParts);
+        const QStringList srcItems = src.path().split(QLatin1Char('/'), Qt::SkipEmptyParts);
 
         // can't copy to root or device, needs storage
         if (srcItems.size() < 2) {
@@ -693,7 +687,7 @@ void MTPSlave::mkdir(const QUrl &url, int)
         return;
     }
 
-    const QStringList pathItems = url.path().split(QLatin1Char('/'), QString::SkipEmptyParts);
+    const QStringList pathItems = url.path().split(QLatin1Char('/'), Qt::SkipEmptyParts);
     if (pathItems.size() > 2) {
         const KMTPDeviceInterface *mtpDevice = m_kmtpDaemon.deviceFromName(pathItems.first());
         if (mtpDevice) {
@@ -722,7 +716,7 @@ void MTPSlave::del(const QUrl &url, bool)
         return;
     }
 
-    const QStringList pathItems = url.path().split(QLatin1Char('/'), QString::SkipEmptyParts);
+    const QStringList pathItems = url.path().split(QLatin1Char('/'), Qt::SkipEmptyParts);
     if (pathItems.size() >= 2) {
         const KMTPDeviceInterface *mtpDevice = m_kmtpDaemon.deviceFromName(pathItems.first());
         if (mtpDevice) {
@@ -766,7 +760,7 @@ void MTPSlave::rename(const QUrl &src, const QUrl &dest, JobFlags flags)
         return;
     }
 
-    const QStringList srcItems = src.path().split(QLatin1Char('/'), QString::SkipEmptyParts);
+    const QStringList srcItems = src.path().split(QLatin1Char('/'), Qt::SkipEmptyParts);
     KMTPDeviceInterface *mtpDevice = m_kmtpDaemon.deviceFromName(srcItems.first());
     if (mtpDevice) {
         // rename Device
@@ -820,7 +814,8 @@ void MTPSlave::virtual_hook(int id, void *data)
     case SlaveBase::GetFileSystemFreeSpace: {
         QUrl *url = static_cast<QUrl *>(data);
         fileSystemFreeSpace(*url);
-    }   break;
+    }
+    break;
     default:
         SlaveBase::virtual_hook(id, data);
     }
@@ -845,7 +840,7 @@ void MTPSlave::fileSystemFreeSpace(const QUrl &url)
         return;
     }
 
-    const QStringList pathItems = url.path().split(QLatin1Char('/'), QString::SkipEmptyParts);
+    const QStringList pathItems = url.path().split(QLatin1Char('/'), Qt::SkipEmptyParts);
 
     // Storage
     if (pathItems.size() > 1) {
@@ -876,4 +871,4 @@ int MTPSlave::waitForCopyOperation(const KMTPStorageInterface *storage)
     return loop.exec();
 }
 
-
+#include "kio_mtp.moc"
