@@ -1,20 +1,9 @@
 /*
     This file is part of the MTP KIOD module, part of the KDE project.
 
-    Copyright (C) 2018 Andreas Krutzler <andreas.krutzler@gmx.net>
+    SPDX-FileCopyrightText: 2018 Andreas Krutzler <andreas.krutzler@gmx.net>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kmtpd.h"
@@ -27,11 +16,11 @@
 #include <Solid/DeviceNotifier>
 
 #include "daemonadaptor.h"
+#include "kiod_kmtpd_debug.h"
+#include "mtpdevice.h"
 
 K_PLUGIN_CLASS_WITH_JSON(KMTPd, "kmtpd.json")
 
-Q_LOGGING_CATEGORY(LOG_KIOD_KMTPD, "kf5.kiod.kmtpd")
-
 KMTPd::KMTPd(QObject *parent, const QList<QVariant> &parameters)
     : KDEDModule(parent)
 {
@@ -108,14 +97,14 @@ void KMTPd::checkDevice(const Solid::Device &solidDevice)
                     if (mtpDevice) {
                         MTPDevice *device = new MTPDevice(QStringLiteral("/modules/kmtpd/device%1").arg(m_devices.count()), mtpDevice, rawDevice, solidDevice.udi(), m_timeout);
                         m_devices.append(device);
-                        emit devicesChanged();
+                        Q_EMIT devicesChanged();
                     } else {
                         qCWarning(LOG_KIOD_KMTPD) << "LIBMTP_Open_Raw_Device_Uncached: Could not open MTP device";
                     }
                 }
             }
         }
-            break;
+        break;
         case LIBMTP_ERROR_GENERAL:
         default:
             qCWarning(LOG_KIOD_KMTPD) << "Unknown connection error";
@@ -164,7 +153,7 @@ void KMTPd::deviceRemoved(const QString &udi)
 
         m_devices.removeOne(device);
         delete device;
-        emit devicesChanged();
+        Q_EMIT devicesChanged();
     }
 }
 
