@@ -1,20 +1,9 @@
 /*
     This file is part of the MTP KIOD module, part of the KDE project.
 
-    Copyright (C) 2018 Andreas Krutzler <andreas.krutzler@gmx.net>
+    SPDX-FileCopyrightText: 2018 Andreas Krutzler <andreas.krutzler@gmx.net>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "mtpstorage.h"
@@ -22,6 +11,7 @@
 #include <QDateTime>
 #include <qplatformdefs.h>
 
+#include "kiod_kmtpd_debug.h"
 #include "mtpdevice.h"
 #include "storageadaptor.h"
 
@@ -31,7 +21,7 @@
 static uint16_t onDataPut(void *, void *priv, uint32_t sendlen, unsigned char *data, uint32_t *putlen)
 {
     MTPStorage *storage = static_cast<MTPStorage *>(priv);
-    emit storage->dataReady(QByteArray(reinterpret_cast<char *>(data), int(sendlen)));
+    Q_EMIT storage->dataReady(QByteArray(reinterpret_cast<char *>(data), int(sendlen)));
     *putlen = sendlen;
 
     return LIBMTP_HANDLER_RETURN_OK;
@@ -40,7 +30,7 @@ static uint16_t onDataPut(void *, void *priv, uint32_t sendlen, unsigned char *d
 static int onDataProgress(const uint64_t sent, const uint64_t total, const void * const priv)
 {
     MTPStorage *storage = const_cast<MTPStorage *>(static_cast<const MTPStorage *>(priv));
-    emit storage->copyProgress(sent, total);
+    Q_EMIT storage->copyProgress(sent, total);
     return LIBMTP_HANDLER_RETURN_OK;
 }
 
@@ -326,7 +316,7 @@ LIBMTP_mtpdevice_t *MTPStorage::getDevice() const
 
 KMTPFile MTPStorage::getFileFromPath(const QString &path)
 {
-    const QStringList pathItems = path.split(QLatin1Char('/'), QString::SkipEmptyParts);
+    const QStringList pathItems = path.split(QLatin1Char('/'), Qt::SkipEmptyParts);
 
     // don't handle the root directory
     if (!pathItems.isEmpty()) {
@@ -490,7 +480,7 @@ int MTPStorage::getFileToHandler(const QString &path)
                 LIBMTP_Dump_Errorstack(getDevice());
                 LIBMTP_Clear_Errorstack(getDevice());
             }
-            emit copyFinished(result);
+            Q_EMIT copyFinished(result);
         });
         return 0;
     }
@@ -513,7 +503,7 @@ int MTPStorage::getFileToFileDescriptor(const QDBusUnixFileDescriptor &descripto
                 LIBMTP_Dump_Errorstack(getDevice());
                 LIBMTP_Clear_Errorstack(getDevice());
             }
-            emit copyFinished(result);
+            Q_EMIT copyFinished(result);
         });
         return 0;
     }
@@ -524,7 +514,7 @@ int MTPStorage::sendFileFromFileDescriptor(const QDBusUnixFileDescriptor &descri
 {
     qCDebug(LOG_KIOD_KMTPD) << "sendFileFromFileDescriptor:" << destinationPath;
 
-    QStringList destItems = destinationPath.split(QLatin1Char('/'), QString::SkipEmptyParts);
+    QStringList destItems = destinationPath.split(QLatin1Char('/'), Qt::SkipEmptyParts);
     if (destItems.isEmpty()) {
         return 1;
     }
@@ -563,7 +553,7 @@ int MTPStorage::sendFileFromFileDescriptor(const QDBusUnixFileDescriptor &descri
                 LIBMTP_Clear_Errorstack(getDevice());
             }
         }
-        emit copyFinished(result);
+        Q_EMIT copyFinished(result);
     });
 
     return 0;
@@ -593,7 +583,7 @@ quint32 MTPStorage::createFolder(const QString &path)
     qCDebug(LOG_KIOD_KMTPD) << "createFolder:" << path;
 
     quint32 folderId = 0;
-    const QStringList pathItems = path.split(QLatin1Char('/'), QString::SkipEmptyParts);
+    const QStringList pathItems = path.split(QLatin1Char('/'), Qt::SkipEmptyParts);
     const quint32 destinationId = queryPath(path);
 
     if (!pathItems.isEmpty() && !destinationId) {
