@@ -1,21 +1,8 @@
 /*  This file is part of the KDE project
-    Copyright (C) 2000 Alexander Neundorf <neundorf@kde.org>,
-        2014 Mathias Tillman <master.homer@gmail.com>
+    SPDX-FileCopyrightText: 2000 Alexander Neundorf <neundorf@kde.org>
+    SPDX-FileCopyrightText: 2014 Mathias Tillman <master.homer@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KIO_NFS_H
@@ -29,14 +16,10 @@
 #include <QMap>
 #include <QString>
 #include <QStringList>
-#include <QTimer>
-#include <QLoggingCategory>
 
 #include "rpc_nfs2_prot.h"
 #include "rpc_nfs3_prot.h"
 
-Q_DECLARE_LOGGING_CATEGORY(LOG_KIO_NFS);
-
 class NFSProtocol;
 
 class NFSSlave : public QObject, public KIO::SlaveBase
