@@ -592,13 +592,13 @@ Result SFTPInternal::sftpOpenConnection(const AuthInfo &info)
         return Result::fail(KIO::ERR_INTERNAL, i18n("Could not disable Nagle's Algorithm."));
     }
 
-    // Don't use any compression
-    rc = ssh_options_set(mSession, SSH_OPTIONS_COMPRESSION_C_S, "none");
+    // Prefer not to use compression
+    rc = ssh_options_set(mSession, SSH_OPTIONS_COMPRESSION_C_S, "none,zlib@openssh.com,zlib");
     if (rc < 0) {
         return Result::fail(KIO::ERR_INTERNAL, i18n("Could not set compression."));
     }
 
-    rc = ssh_options_set(mSession, SSH_OPTIONS_COMPRESSION_S_C, "none");
+    rc = ssh_options_set(mSession, SSH_OPTIONS_COMPRESSION_S_C, "none,zlib@openssh.com,zlib");
     if (rc < 0) {
         return Result::fail(KIO::ERR_INTERNAL, i18n("Could not set compression."));
     }
@@ -1308,7 +1308,7 @@ Result SFTPInternal::sftpGet(const QUrl &url, KIO::fileoffset_t offset, int fd)
         }
 
         filedata.clear();
-        const size_t bytesread = request.readChunks(filedata);
+        const auto bytesread = request.readChunks(filedata);
         // Read pending get requests
         if (bytesread == -1) {
             return Result::fail(KIO::ERR_CANNOT_READ, url.toString());
