@@ -52,7 +52,7 @@ KIO::UDSEntry DNSSDDiscovery::toEntry() const
 DNSSDDiscoverer::DNSSDDiscoverer()
 {
     connect(&m_browser, &KDNSSD::ServiceBrowser::serviceAdded,
-            this, [=](KDNSSD::RemoteService::Ptr service){
+    this, [=](KDNSSD::RemoteService::Ptr service) {
         qCDebug(KIO_SMB_LOG) << "DNSSD added:"
                              << service->serviceName()
                              << service->type()
@@ -71,7 +71,7 @@ DNSSDDiscoverer::DNSSDDiscoverer()
 
         connect(service.data(), &KDNSSD::RemoteService::resolved, this, [=] {
             ++m_resolvedCount;
-            emit newDiscovery(Discovery::Ptr(new DNSSDDiscovery(service)));
+            Q_EMIT newDiscovery(Discovery::Ptr(new DNSSDDiscovery(service)));
             maybeFinish();
         });
 
@@ -104,6 +104,6 @@ bool DNSSDDiscoverer::isFinished() const
 void DNSSDDiscoverer::maybeFinish()
 {
     if (isFinished()) {
-        emit finished();
+        Q_EMIT finished();
     }
 }
