@@ -101,7 +101,8 @@ void SMBSlave::special(const QByteArray &data)
             error(KIO::ERR_CANNOT_MOUNT, i18n("Mounting of share \"%1\" from host \"%2\" by user \"%3\" failed.\n%4", share, host, user, mybuf + '\n' + mystderr));
             return;
         }
-    } break;
+    }
+    break;
     case 2:
     case 4: {
         QString mountPoint;
@@ -145,7 +146,8 @@ void SMBSlave::special(const QByteArray &data)
                 return;
             }
         }
-    } break;
+    }
+    break;
     default:
         break;
     }
