@@ -10,7 +10,7 @@
 //              Frank Schwanz <schwanz@fh-brandenburg.de>
 //---------------------------------------------------------------------------
 //
-// Copyright (c) 2000  Caldera Systems, Inc.
+// SPDX-FileCopyrightText: 2000 Caldera Systems Inc.
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -79,15 +79,29 @@ public:
      */
     SMBUrlType getType() const;
 
-    void setPass(const QString &_txt) { QUrl::setPassword(_txt); updateCache(); }
-    void setUser(const QString &_txt) { QUrl::setUserName(_txt); updateCache(); }
-    void setHost(const QString &_txt) { QUrl::setHost(_txt); updateCache(); }
-    void setPath(const QString &_txt) { QUrl::setPath(_txt); updateCache(); }
+    void setPass(const QString &_txt) {
+        QUrl::setPassword(_txt);
+        updateCache();
+    }
+    void setUser(const QString &_txt) {
+        QUrl::setUserName(_txt);
+        updateCache();
+    }
+    void setHost(const QString &_txt) {
+        QUrl::setHost(_txt);
+        updateCache();
+    }
+    void setPath(const QString &_txt) {
+        QUrl::setPath(_txt);
+        updateCache();
+    }
 
-     /**
-     * Return a URL that is suitable for libsmbclient
-     */
-    QByteArray toSmbcUrl() const { return m_surl; }
+    /**
+    * Return a URL that is suitable for libsmbclient
+    */
+    QByteArray toSmbcUrl() const {
+        return m_surl;
+    }
 
     /**
      * Returns the partial URL.
